@@ -1,6 +1,6 @@
 package HTTP::Any;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 1;
 
@@ -154,9 +154,16 @@ When not specified, see the default behavior of Curl (reverse of CURLOPT_FORBID_
 
 =item proxy
 
-http and https proxy
+http and socks proxy
 
  proxy => "$host:$port"
+ or
+ proxy => "$scheme://$host:$port"
+ where scheme can be one of the: http, socks (socks5), socks5, socks4.
+
+Install LWP::Protocol::socks to use socks proxy with LWP.
+
+Use AnyEvent::HTTP::Socks instead AnyEvent::HTTP for socks proxy.
 
 =item max_size
 
