@@ -25,7 +25,16 @@ sub do_http {
 	$args{timeout} = $$opt{timeout} if $$opt{timeout};
 
 	if (my $proxy = $$opt{proxy}) {
-		$args{proxy} = [split ":", $proxy];
+		if ($proxy =~ m/^socks/) {
+			$proxy =~ s!^socks://!socks5://!;
+			$args{socks} = $proxy;
+		} elsif ($proxy =~ m!^(\w+://)?(.+):(\d+)$!) {
+			if ($1) {
+				$args{proxy} = [$2, $3, $1];
+			} else {
+				$args{proxy} = [$2, $3];
+			}
+		}
 	}
 
 	if ($$opt{cookie}) {
