@@ -71,9 +71,8 @@ sub do_http {
 	$easy->setopt(CURLOPT_TIMEOUT, $$opt{timeout}) if $$opt{timeout};
 
 	if (my $proxy = $$opt{proxy}) {
-		my ($h, $p) = split ":", $proxy;
-		$easy->setopt(CURLOPT_PROXY,     $h);
-		$easy->setopt(CURLOPT_PROXYPORT, $p);
+		$proxy =~ s!^socks://!socks5://!;
+		$easy->setopt(CURLOPT_PROXY, $proxy);
 	}
 
 	$easy->setopt(CURLOPT_ACCEPT_ENCODING, "gzip") if $$opt{gzip};
@@ -124,8 +123,10 @@ sub do_http {
 				$$headers{"Status"} = 599;
 				$$headers{"Reason"} = "Timeout";
 			}
+			$easy = undef;
 			$cb->($is_success, $body, $headers, $redirects);
 		} else {
+			$easy = undef;
 			$cb->(0, undef, { Status => 500, Reason => "$result", URL => $url }, []);
 		}
 
@@ -162,7 +163,7 @@ sub _parse_headers {
 	my ($url, $h) = @_;
 	my ($status_line, @h) = split /\r?\n/, $h;
 	my ($status, $reason) = $status_line =~ m/HTTP\/\d\.\d\s+(\d+)(?:\s+(.+))?/;
-	# ToDo  $reason  ,    $status?
+	# ToDo Когда $reason не указан, формировать на основе $status?
 
 	my %h = ();
 	foreach (@h) {
