@@ -21,7 +21,12 @@ sub do_http {
 	}
 
 	if (my $proxy = $$opt{proxy}) {
-		$ua->proxy(['http', 'https'] => "http://$proxy");
+		unless ($proxy =~ m!^\w+://!) {
+			$proxy = "http://$proxy"
+		} else {
+			$proxy =~ s!^socks5://!socks://!;
+		}
+		$ua->proxy(['http', 'https'] => $proxy);
 	}
 
 	my $method = $$opt{method} || "GET";
@@ -106,7 +111,15 @@ sub do_http {
 	my $is_success = $res->is_success || 0;
 
 	if ($$h{'client-aborted'}) {
-		$cb->($is_success, "", $h, \@hr);
+		if ($$h{'client-aborted'} eq 'max_size') {
+			$$h{Reason} = 'MaxSize';
+		} elsif ($$h{'client-aborted'} eq 'die') {
+			if ($$h{'x-died'} =~ m/timeout/) {
+				$$h{Reason} = 'Timeout';
+			}
+		}
+		$$h{Status} = 599;
+		$cb->(0, "", $h, \@hr);
 		return;
 	}
 
